"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePaintBright = exports.usePaintLight = exports.usePaintSat = void 0;
const react_1 = require("react");
const tinycolor2_1 = __importDefault(require("tinycolor2"));
const usePaintHue = (canvas, squareSize) => {
    (0, react_1.useEffect)(() => {
        const ctx = canvas?.current?.getContext('2d', { willReadFrequently: true });
        if (ctx) {
            ctx.rect(0, 0, squareSize, 14);
            const gradient = ctx.createLinearGradient(0, 0, squareSize, 0);
            for (let i = 0; i <= 360; i += 30) {
                gradient.addColorStop(i / 360, `hsl(${i}, 100%, 50%)`);
            }
            ctx.fillStyle = gradient;
            ctx.fill();
        }
    }, [canvas, squareSize]);
};
exports.default = usePaintHue;
const usePaintSat = (canvas, h, l, squareSize) => {
    (0, react_1.useEffect)(() => {
        const ctx = canvas?.current?.getContext('2d', { willReadFrequently: true });
        if (ctx) {
            ctx.rect(0, 0, squareSize, 14);
            const gradient = ctx.createLinearGradient(0, 0, squareSize, 0);
            for (let i = 0; i <= 100; i += 10) {
                gradient.addColorStop(i / 100, `hsl(${h}, ${i}%, ${l}%)`);
            }
            ctx.fillStyle = gradient;
            ctx.fill();
        }
    }, [canvas, h, l, squareSize]);
};
exports.usePaintSat = usePaintSat;
const usePaintLight = (canvas, h, s, squareSize) => {
    (0, react_1.useEffect)(() => {
        const ctx = canvas?.current?.getContext('2d', { willReadFrequently: true });
        if (ctx) {
            ctx.rect(0, 0, squareSize, 14);
            const gradient = ctx.createLinearGradient(0, 0, squareSize, 0);
            for (let i = 0; i <= 100; i += 10) {
                gradient.addColorStop(i / 100, `hsl(${h}, ${s}%, ${i}%)`);
            }
            ctx.fillStyle = gradient;
            ctx.fill();
        }
    }, [canvas, h, s, squareSize]);
};
exports.usePaintLight = usePaintLight;
const usePaintBright = (canvas, h, s, squareSize) => {
    (0, react_1.useEffect)(() => {
        const ctx = canvas?.current?.getContext('2d', { willReadFrequently: true });
        if (ctx) {
            ctx.rect(0, 0, squareSize, 14);
            const gradient = ctx.createLinearGradient(0, 0, squareSize, 0);
            for (let i = 0; i <= 100; i += 10) {
                const hsl = (0, tinycolor2_1.default)({ h: h, s: s, v: i });
                gradient.addColorStop(i / 100, hsl.toHslString());
            }
            ctx.fillStyle = gradient;
            ctx.fill();
        }
    }, [canvas, h, s, squareSize]);
};
exports.usePaintBright = usePaintBright;
